#[non_exhaustive]pub enum VideoStandardTransitionType {
Show 73 variants
None,
BarWipeLr,
BarWipeTb,
BoxWipeTl,
BoxWipeTr,
BoxWipeBr,
BoxWipeBl,
FourBoxWipeCi,
FourBoxWipeCo,
BarndoorV,
BarndoorH,
BoxWipeTc,
BoxWipeRc,
BoxWipeBc,
BoxWipeLc,
DiagonalTl,
DiagonalTr,
BowtieV,
BowtieH,
BarndoorDbl,
BarndoorDtl,
MiscDiagonalDbd,
MiscDiagonalDd,
VeeD,
VeeL,
VeeU,
VeeR,
BarnveeD,
BarnveeL,
BarnveeU,
BarnveeR,
IrisRect,
ClockCw12,
ClockCw3,
ClockCw6,
ClockCw9,
PinwheelTbv,
PinwheelTbh,
PinwheelFb,
FanCt,
FanCr,
DoublefanFov,
DoublefanFoh,
SinglesweepCwt,
SinglesweepCwr,
SinglesweepCwb,
SinglesweepCwl,
DoublesweepPv,
DoublesweepPd,
DoublesweepOv,
DoublesweepOh,
FanT,
FanR,
FanB,
FanL,
DoublefanFiv,
DoublefanFih,
SinglesweepCwtl,
SinglesweepCwbl,
SinglesweepCwbr,
SinglesweepCwtr,
DoublesweepPdtl,
DoublesweepPdbl,
SaloondoorT,
SaloondoorL,
SaloondoorB,
SaloondoorR,
WindshieldR,
WindshieldU,
WindshieldV,
WindshieldH,
Crossfade,
FadeIn,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
BarWipeLr
BarWipeTb
BoxWipeTl
BoxWipeTr
BoxWipeBr
BoxWipeBl
FourBoxWipeCi
FourBoxWipeCo
BarndoorV
BarndoorH
BoxWipeTc
BoxWipeRc
BoxWipeBc
BoxWipeLc
DiagonalTl
DiagonalTr
BowtieV
BowtieH
BarndoorDbl
BarndoorDtl
MiscDiagonalDbd
MiscDiagonalDd
VeeD
VeeL
VeeU
VeeR
BarnveeD
BarnveeL
BarnveeU
BarnveeR
IrisRect
ClockCw12
ClockCw3
ClockCw6
ClockCw9
PinwheelTbv
PinwheelTbh
PinwheelFb
FanCt
FanCr
DoublefanFov
DoublefanFoh
SinglesweepCwt
SinglesweepCwr
SinglesweepCwb
SinglesweepCwl
DoublesweepPv
DoublesweepPd
DoublesweepOv
DoublesweepOh
FanT
FanR
FanB
FanL
DoublefanFiv
DoublefanFih
SinglesweepCwtl
SinglesweepCwbl
SinglesweepCwbr
SinglesweepCwtr
DoublesweepPdtl
DoublesweepPdbl
SaloondoorT
SaloondoorL
SaloondoorB
SaloondoorR
WindshieldR
WindshieldU
WindshieldV
WindshieldH
Crossfade
FadeIn
Available on crate feature
v1_22 only.Trait Implementations
Sourceimpl Clone for VideoStandardTransitionType
impl Clone for VideoStandardTransitionType
Sourcefn clone(&self) -> VideoStandardTransitionType
fn clone(&self) -> VideoStandardTransitionType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VideoStandardTransitionType
impl Debug for VideoStandardTransitionType
Sourceimpl From<VideoStandardTransitionType> for Value
impl From<VideoStandardTransitionType> for Value
Sourcefn from(v: VideoStandardTransitionType) -> Self
fn from(v: VideoStandardTransitionType) -> Self
Converts to this type from the input type.
Sourceimpl<'a> FromValue<'a> for VideoStandardTransitionType
impl<'a> FromValue<'a> for VideoStandardTransitionType
Sourcetype Checker = GenericValueTypeChecker<VideoStandardTransitionType>
type Checker = GenericValueTypeChecker<VideoStandardTransitionType>
Value type checker.
Sourceunsafe fn from_value(value: &'a Value) -> Self
unsafe fn from_value(value: &'a Value) -> Self
Get the contained value from a
Value. Read moreSourceimpl HasParamSpec for VideoStandardTransitionType
impl HasParamSpec for VideoStandardTransitionType
type ParamSpec = ParamSpecEnum
Sourcetype SetValue = VideoStandardTransitionType
type SetValue = VideoStandardTransitionType
Preferred value to be used as setter for the associated ParamSpec.
type BuilderFn = fn(&str, VideoStandardTransitionType) -> ParamSpecEnumBuilder<'_, VideoStandardTransitionType>
fn param_spec_builder() -> Self::BuilderFn
Sourceimpl Hash for VideoStandardTransitionType
impl Hash for VideoStandardTransitionType
Sourceimpl Ord for VideoStandardTransitionType
impl Ord for VideoStandardTransitionType
Sourcefn cmp(&self, other: &VideoStandardTransitionType) -> Ordering
fn cmp(&self, other: &VideoStandardTransitionType) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VideoStandardTransitionType
impl PartialEq for VideoStandardTransitionType
Sourcefn eq(&self, other: &VideoStandardTransitionType) -> bool
fn eq(&self, other: &VideoStandardTransitionType) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for VideoStandardTransitionType
impl PartialOrd for VideoStandardTransitionType
Sourceimpl StaticType for VideoStandardTransitionType
impl StaticType for VideoStandardTransitionType
Sourcefn static_type() -> Type
fn static_type() -> Type
Returns the type identifier of
Self.Sourceimpl ValueType for VideoStandardTransitionType
impl ValueType for VideoStandardTransitionType
Sourcetype Type = VideoStandardTransitionType
type Type = VideoStandardTransitionType
Type to get the
Type from. Read moreimpl Copy for VideoStandardTransitionType
impl Eq for VideoStandardTransitionType
impl StructuralPartialEq for VideoStandardTransitionType